package errs

import (
	"fmt"
	"os"
	"testing"

	"gorm.io/driver/sqlite"
	"gorm.io/gorm"
)

func TestErrs(t *testing.T) {
	//= Init DS >
	ds, e := gorm.Open(sqlite.Open("errs_test.sqlite3"), nil)
	if e != nil {
		t.Fatal(e)
	}
	err := InitDS(ds)
	if err != nil {
		t.Fatal(err)
	}
	//< InitDS =
	//= InitFS >
	f, e := os.OpenFile("errs_test.err", os.O_CREATE|os.O_APPEND|os.O_WRONLY, 0664)
	if e != nil {
		t.Fatal(e)
	}
	err = InitFS(f)
	if err != nil {
		t.Fatal(err)
	}
	//< InitFS =

	err = RaiseError(ErrError, "Some new error")
	if err != nil {
		UpError(err)
	}

	RaiseError(ErrNoError, "It's record with NoError")

	//= GetDS Recs >
	ers := DSList(0, 10)
	if ers == nil {
		t.Fatal("Error while retrieve DS Records")
	}
	fmt.Println("Errors total count: ", ers.Total)
	fmt.Println("Received count: ", len(ers.Items))
	if ers.Total > 10 {
		ers = DSList(int(ers.Total-5), 10)
		if ers == nil {
			t.Fatal("Error while retrive DS Records")
		}
		fmt.Println("Total count: ", ers.Total)
		fmt.Println("Received count: ", len(ers.Items))
	}
	//< GetDS Recs =

	//= GetDS filtered recs >
	ers = DSList(0, 10, "code:ErrNoError")
	if ers == nil {
		t.Fatal("Error while retrieve DS filtered records")
	}
	fmt.Println("Filetered total count: ", ers.Total)
	fmt.Println("Received count: ", len(ers.Items))
	if ers.Total > 10 {
		ers = DSList(int(ers.Total-5), 10, "code:ErrNoError")
		if ers == nil {
			t.Fatal("Error receive DS records")
		}
		fmt.Println("Total count: ", ers.Total)
		fmt.Println("Received count: ", len(ers.Items))
	}
	//< GetDS filtered recs =
}
